@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber::Errors;
-$Test::BDD::Cucumber::Errors::VERSION = '0.41';
+$Test::BDD::Cucumber::Errors::VERSION = '0.44';
 use strict;
 use warnings;
 
@@ -13,7 +13,7 @@ Test::BDD::Cucumber::Errors - Consistently formatted errors
 
 =head1 VERSION
 
-version 0.41
+version 0.44
 
 =head1 DESCRIPTION
 
@@ -83,14 +83,13 @@ sub parse_error_from_line {
           sprintf( "% 3d%s    %s\n", $actual_line, $mark, $lines[$_] );
     }
 
-    my $to_return =
-        sprintf( $error,
-            $feature_filename, $feature_line,
-            $caller_filename,  $caller_line,
-            $feature_filename, $formatted_lines,
-            ( '-' x ( ( length $feature_filename ) + 8 ) ) );
+    my $to_return = sprintf( $error,
+        $feature_filename, $feature_line,
+        $caller_filename,  $caller_line,
+        $feature_filename, $formatted_lines,
+        ( '-' x ( ( length $feature_filename ) + 8 ) ) );
 
-    utf8::encode( $to_return );
+    utf8::encode($to_return);
     return $to_return;
 }
 
