@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.41';
+$Test::BDD::Cucumber::Executor::VERSION = '0.44';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.41
+version 0.44
 
 =head1 DESCRIPTION
 
@@ -58,8 +58,8 @@ END
     croak $message;
 }
 
-$Test::Builder::Test
-    = Test::BDD::Cucumber::TestBuilderDelegator->new( Test::Builder->new() );
+$Test::Builder::Test =
+  Test::BDD::Cucumber::TestBuilderDelegator->new( Test::Builder->new() );
 
 use Test::BDD::Cucumber::StepContext;
 use Test::BDD::Cucumber::Util;
@@ -70,6 +70,34 @@ has '_bail_out' => ( is => 'rw', isa => 'Bool', default => 0 );
 
 =head1 METHODS
 
+=head2 extensions
+
+=head2 add_extensions
+
+The attributes C<extensions> is an arrayref of
+L<Test::BDD::Cucumber::Extension> extensions. Extensions have their
+hook-functions called by the Executor at specific points in the BDD feature
+execution.
+
+B<C<<add_extensions>> adds items in FIFO using unshift()>, and are called in
+reverse order at the end hook; this means that if you:
+
+  add_extensions( 1 );
+  add_extensions( 2, 3 );
+
+The C<pre_*> will be called in order 2, 3, 1, and C<post_*> will be called in
+1, 3, 2.
+
+=cut
+
+has extensions => (
+    is      => 'ro',
+    isa     => 'ArrayRef',
+    traits  => ['Array'],
+    default => sub { [] },
+    handles => { add_extensions => 'unshift' },
+);
+
 =head2 steps
 
 =head2 add_steps
@@ -132,8 +160,8 @@ sub execute {
     my $feature_stash = {};
 
     $harness->feature($feature);
-    my @background = (
-        $feature->background ? ( background => $feature->background ) : () );
+    my @background =
+      ( $feature->background ? ( background => $feature->background ) : () );
 
     # Get all scenarios
     my @scenarios = @{ $feature->scenarios() };
@@ -143,11 +171,13 @@ sub execute {
         @scenarios = $tag_spec->filter(@scenarios);
     }
 
+    $_->pre_feature( $feature, $feature_stash ) for @{ $self->extensions };
     for my $scenario (@scenarios) {
 
         # Execute the scenario itself
         $self->execute_scenario(
-            {   @background,
+            {
+                @background,
                 scenario      => $scenario,
                 feature       => $feature,
                 feature_stash => $feature_stash,
@@ -155,6 +185,8 @@ sub execute {
             }
         );
     }
+    $_->post_feature( $feature, $feature_stash, 'no' )
+      for reverse @{ $self->extensions };
 
     $harness->feature_done($feature);
 }
@@ -188,11 +220,11 @@ sub execute_scenario {
     my ( $self, $options ) = @_;
     my ( $feature, $feature_stash, $harness, $outline, $background_obj,
         $incoming_scenario_stash, $incoming_outline_stash )
-        = @$options{
+      = @$options{
         qw/ feature feature_stash harness scenario background scenario_stash
-            outline_stash
-            /
-        };
+          outline_stash
+          /
+      };
 
     my $is_background = $outline->background;
 
@@ -237,13 +269,17 @@ sub execute_scenario {
             $scenario_stash->{'longest_step_line'} );
 
         if ( not $is_background ) {
+            $_->pre_scenario( $outline, $feature_stash, $scenario_stash )
+              for @{ $self->extensions };
+
             for my $before_step ( @{ $self->{'steps'}->{'before'} || [] } ) {
 
                 # Set up a context
                 my $context = Test::BDD::Cucumber::StepContext->new(
                     { %context_defaults, verb => 'before', } );
 
-                my $result = $self->dispatch( $context, $before_step,
+                my $result =
+                  $self->dispatch( $context, $before_step,
                     $outline_stash->{'short_circuit'}, 0 );
 
                 # If it didn't pass, short-circuit the rest
@@ -257,7 +293,8 @@ sub execute_scenario {
         # execute_scenario...
         if ($background_obj) {
             $self->execute_scenario(
-                {   is_background  => 1,
+                {
+                    is_background  => 1,
                     scenario       => $background_obj,
                     feature        => $feature,
                     feature_stash  => $feature_stash,
@@ -271,12 +308,13 @@ sub execute_scenario {
         foreach my $step ( @{ $outline->steps } ) {
 
             # Multiply out any placeholders
-            my $text = $self->add_placeholders( $step->text, $dataset,
-                $step->line );
+            my $text =
+              $self->add_placeholders( $step->text, $dataset, $step->line );
 
             # Set up a context
             my $context = Test::BDD::Cucumber::StepContext->new(
-                {   %context_defaults,
+                {
+                    %context_defaults,
 
                     # Data portion
                     columns => $step->columns || [],
@@ -291,7 +329,8 @@ sub execute_scenario {
                 }
             );
 
-            my $result = $self->find_and_dispatch( $context,
+            my $result =
+              $self->find_and_dispatch( $context,
                 $outline_stash->{'short_circuit'}, 0 );
 
             # If it didn't pass, short-circuit the rest
@@ -311,6 +350,10 @@ sub execute_scenario {
                 # All After steps should happen, to ensure cleanup
                 my $result = $self->dispatch( $context, $after_step, 0, 0 );
             }
+            $_->post_scenario( $outline, $feature_stash, $scenario_stash,
+                $outline_stash->{'short_circuit'} )
+              for reverse @{ $self->extensions };
+
         }
 
         $harness->$harness_stop( $outline, $dataset );
@@ -354,25 +397,29 @@ sub find_and_dispatch {
     # Short-circuit if we need to
     return $self->skip_step( $context, 'pending',
         "Short-circuited from previous tests", 0 )
-        if $short_circuit;
+      if $short_circuit;
 
     # Try and find a matching step
     my $step = first { $context->text =~ $_->[0] }
     @{ $self->{'steps'}->{ $context->verb } || [] },
-        @{ $self->{'steps'}->{'step'} || [] };
+      @{ $self->{'steps'}->{'step'} || [] };
 
     # Deal with the simple case of no-match first of all
     unless ($step) {
-        my $message
-            = "No matching step definition for: "
-            . $context->verb . ' '
-            . $context->text;
-        my $result = $self->skip_step( $context, 'undefined',
-            $message, $redispatch );
+        my $message =
+            "No matching step definition for: "
+          . $context->verb . ' '
+          . $context->text;
+        my $result =
+          $self->skip_step( $context, 'undefined', $message, $redispatch );
         return $result;
     }
 
-    return $self->dispatch( $context, $step, 0, $redispatch );
+    $_->pre_step( $step, $context ) for @{ $self->extensions };
+    my $result = $self->dispatch( $context, $step, 0, $redispatch );
+    $_->post_step( $step, $context, $result eq 'passing' )
+      for reverse @{ $self->extensions };
+    return $result;
 }
 
 =head2 dispatch
@@ -390,7 +437,7 @@ sub dispatch {
 
     return $self->skip_step( $context, 'pending',
         "Short-circuited from previous tests", $redispatch )
-        if $short_circuit;
+      if $short_circuit;
 
     # Execute the step definition
     my ( $regular_expression, $coderef ) = @$step;
@@ -410,7 +457,7 @@ sub dispatch {
 
     # Make a minimum pass
     $tb_return->{'builder'}
-        ->ok( 1, "Starting to execute step: " . $context->text );
+      ->ok( 1, "Starting to execute step: " . $context->text );
 
     my $step_name = $redispatch ? 'sub_step' : 'step';
     my $step_done_name = $step_name . '_done';
@@ -472,14 +519,15 @@ sub dispatch {
 
         # Create the result object
         $result = Test::BDD::Cucumber::Model::Result->new(
-            {   result => $status,
+            {
+                result => $status,
                 output => $output
             }
         );
     }
 
-    my @clean_matches
-        = $self->_extract_match_strings( $context->text, \@match_locations );
+    my @clean_matches =
+      $self->_extract_match_strings( $context->text, \@match_locations );
     @clean_matches = [ 0, $context->text ] unless @clean_matches;
 
     # Say the step is done, and return the result. Happens outside
@@ -495,12 +543,12 @@ sub _extract_match_strings {
 
     # Clean up the match locations
     my @match_locations = grep {
-        ( $_->[0] != $_->[1] ) &&   # No zero-length matches
-                                    # And nothing that matched the full string
-            ( !( ( $_->[0] == 0 ) && ( ( $_->[1] == length $text ) ) ) )
-        } grep {
+        ( $_->[0] != $_->[1] ) &&    # No zero-length matches
+                                     # And nothing that matched the full string
+          ( !( ( $_->[0] == 0 ) && ( ( $_->[1] == length $text ) ) ) )
+      } grep {
         defined $_ && ref $_ && defined $_->[0] && defined $_->[1]
-        } @$locations;
+      } @$locations;
 
     return unless @match_locations;
 
@@ -512,7 +560,7 @@ sub _extract_match_strings {
         # expected for nested matches
         no warnings;
         $range->addrange( $_->[0] . '..' . ( $_->[1] - 1 ) )
-            for @match_locations;
+          for @match_locations;
     }
 
     # Walk the string, splitting
@@ -535,16 +583,16 @@ sub _test_status {
     my $self    = shift;
     my $builder = shift;
 
-    my $results
-        = $builder->can("history")
-        ? $self->_test_status_from_history($builder)
-        : $self->_test_status_from_details($builder);
+    my $results =
+        $builder->can("history")
+      ? $self->_test_status_from_history($builder)
+      : $self->_test_status_from_details($builder);
 
     # Turn that in to a Result status
     return
-          $results->{'fail'} ? 'failing'
-        : $results->{'todo'} ? 'pending'
-        :                      'passing';
+        $results->{'fail'} ? 'failing'
+      : $results->{'todo'} ? 'pending'
+      :                      'passing';
 }
 
 sub _test_status_from_details {
@@ -599,7 +647,8 @@ sub skip_step {
 
     # Create a result object
     my $result = Test::BDD::Cucumber::Model::Result->new(
-        {   result => $type,
+        {
+            result => $type,
             output => '1..0 # SKIP ' . $reason
         }
     );
