@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.41';
+$Test::BDD::Cucumber::Parser::VERSION = '0.44';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.41
+version 0.44
 
 =head1 DESCRIPTION
 
@@ -135,7 +135,12 @@ sub _extract_feature_name {
             push( @feature_tags, @tags );
 
         } else {
-            die parse_error_from_line( 'Malformed feature line (expecting: /^(?:' . $self->{langdef}->{feature} . '): (.+)/', $line );
+            die parse_error_from_line(
+                'Malformed feature line (expecting: /^(?:'
+                  . $self->{langdef}->{feature}
+                  . '): (.+)/',
+                $line
+            );
         }
     }
 
@@ -199,9 +204,10 @@ m/^((?:$langdef->{background})|(?:$langdef->{scenario})|(?:$langdef->{scenario_o
 
             # Catch Scenario outlines without examples
             if ( $type =~ m/^($langdef->{scenario_outline})/
-                   && ! @{$scenario->data} ) {
+                && !@{ $scenario->data } )
+            {
                 die parse_error_from_line(
-                "Outline scenario expects 'Examples:' section", $line)
+                    "Outline scenario expects 'Examples:' section", $line );
             }
 
             if ( $type =~ m/^($langdef->{background})/ ) {
